@@ -381,12 +381,18 @@ class OpenStackCharm(BaseOpenStackCharm,
         if self.config_defined_ssl_key and self.config_defined_ssl_cert:
             ssl_artifacts = []
             for ep_type in [os_ip.INTERNAL, os_ip.ADMIN, os_ip.PUBLIC]:
+                # Not all charms have all bindings to skip if unavailable
+                try:
+                    cn = os_ip.resolve_address(endpoint_type=ep_type)
+                except hookenv.NoNetworkBinding:
+                    continue
+
                 ssl_artifacts.append({
                     'key': self.config_defined_ssl_key.decode('utf-8'),
                     'cert': self.config_defined_ssl_cert.decode('utf-8'),
                     'ca': (self.config_defined_ssl_ca.decode('utf-8')
                            if self.config_defined_ssl_ca else None),
-                    'cn': os_ip.resolve_address(endpoint_type=ep_type)})
+                    'cn': cn})
             return ssl_artifacts
         elif certificates_interface:
             keys_and_certs = []
@@ -428,6 +434,10 @@ class OpenStackCharm(BaseOpenStackCharm,
     def config_defined_ssl_ca(self):
         return self._get_b64decode_for('ssl_ca')
 
+    def config_changed(self):
+        tls = reactive.endpoint_from_flag('certificates.available')
+        self.configure_tls(certificates_interface=tls)
+
     def configure_ssl(self, keystone_interface=None):
         """DEPRECATED Configure SSL certificates and keys.
 
@@ -751,7 +761,7 @@ class HAOpenStackCharm(OpenStackAPICharm):
             ['a2query', '-s', 'openstack_https_frontend'])
         if check_enabled:
             subprocess.check_call(['a2ensite', 'openstack_https_frontend'])
-            ch_host.service_reload('apache2', restart_on_failure=True)
+            self.service_reload('apache2', restart_on_failure=True)
 
     def configure_apache(self):
         if self.apache_enabled():
@@ -928,7 +938,7 @@ class HAOpenStackCharm(OpenStackAPICharm):
                 subprocess.check_call(['a2enmod', module])
                 restart = True
         if restart:
-            ch_host.service_restart('apache2')
+            self.service_restart('apache2')
 
     def configure_tls(self, certificates_interface=None):
         """Configure TLS certificates and keys
@@ -969,7 +979,7 @@ class HAOpenStackCharm(OpenStackAPICharm):
                     os.path.join('/etc/apache2/ssl/', self.name))
                 if not os_utils.snap_install_requested() and changed:
                     self.configure_apache()
-                    ch_host.service_reload('apache2')
+                    self.service_reload('apache2')
 
                 self.remove_state('ssl.requested')
                 self.set_state('ssl.enabled', True)
