@@ -413,15 +413,32 @@ class BaseOpenStackCharm(object, metaclass=BaseOpenStackCharmMeta):
                 charm_instance=self)
         return self.__options
 
+    @property
+    def active_api_ports(self):
+        """Return the api port map adjusting ports as required.
+        """
+        # If charm class sets ssl_port_bump to True then
+        # prepend a 1 to the port number eg 8779 -> 18779
+        ssl_port_bump = getattr(self, 'ssl_port_bump', False)
+        if ssl_port_bump and self.get_state('ssl.enabled'):
+            _api_ports = {}
+            for svc in self.api_ports:
+                _api_ports[svc] = {}
+                for ep_type, port in self.api_ports[svc].items():
+                    _api_ports[svc][ep_type] = int("1{}".format(port))
+            return _api_ports
+        else:
+            return self.api_ports
+
     def api_port(self, service, endpoint_type=os_ip.PUBLIC):
         """Return the API port for a particular endpoint type from the
-        self.api_ports{}.
+        self.active_api_ports{}.
 
         :param service: string for service name
         :param endpoing_type: one of charm.openstack.ip.PUBLIC| INTERNAL| ADMIN
         :returns: port (int)
         """
-        return self.api_ports[service][endpoint_type]
+        return self.active_api_ports[service][endpoint_type]
 
     def set_state(self, state, value=None):
         """proxy for charms.reactive.bus.set_state()"""
@@ -685,6 +702,50 @@ class BaseOpenStackCharmActions(object):
         """
         return self.restart_map
 
+    def service_stop(self, service_name):
+        """Stop the specified service.
+
+        Meant to be overridden by child classes in scenarios where clustering
+        software like Pacemaker is used.
+
+        :param service_name: The service to stop.
+        :type service_name: str
+        """
+        ch_host.service_stop(service_name)
+
+    def service_start(self, service_name):
+        """Start the specified service.
+
+        Meant to be overridden by child classes in scenarios where clustering
+        software like Pacemaker is used.
+
+        :param service_name: The service to start.
+        :type service_name: str
+        """
+        ch_host.service_start(service_name)
+
+    def service_restart(self, service_name):
+        """Restart the specified service.
+
+        Meant to be overridden by child classes in scenarios where clustering
+        software like Pacemaker is used.
+
+        :param service_name: The service to restart.
+        :type service_name: str
+        """
+        ch_host.service_restart(service_name)
+
+    def service_reload(self, service_name, restart_on_failure=False):
+        """Reload the specified service.
+
+        Meant to be overridden by child classes in scenarios where clustering
+        software like Pacemaker is used.
+
+        :param service_name: The service to reload.
+        :type service_name: str
+        """
+        ch_host.service_reload(service_name, restart_on_failure)
+
     @contextlib.contextmanager
     def restart_on_change(self):
         """Restart the services in the self.restart_map{} attribute if any of
@@ -704,16 +765,16 @@ class BaseOpenStackCharmActions(object):
                 restarts += self.full_restart_map[path]
         services_list = list(collections.OrderedDict.fromkeys(restarts).keys())
         for service_name in services_list:
-            ch_host.service_stop(service_name)
+            self.service_stop(service_name)
         for service_name in services_list:
-            ch_host.service_start(service_name)
+            self.service_start(service_name)
 
     def restart_all(self):
         """Restart all the services configured in the self.services[]
         attribute.
         """
         for svc in self.services:
-            ch_host.service_restart(svc)
+            self.service_restart(svc)
 
     def render_all_configs(self, adapters_instance=None):
         """Render (write) all of the config files identified as the keys in the
@@ -885,7 +946,7 @@ class BaseOpenStackCharmActions(object):
         :param ports: List of api port numbers or None.
         """
         ports = list(map(int, (
-            ports or self._default_port_list(self.api_ports or {}))))
+            ports or self._default_port_list(self.active_api_ports or {}))))
         current_ports = list(map(int, self.opened_ports()))
         ports_to_open = set(ports).difference(current_ports)
         ports_to_close = set(current_ports).difference(ports)
@@ -1217,7 +1278,7 @@ class BaseOpenStackCharmAssessStatus(object):
         """
         return os_utils._ows_check_if_paused(
             services=self.services,
-            ports=self.ports_to_check(self.api_ports))
+            ports=self.ports_to_check(self.active_api_ports))
 
     def ports_to_check(self, ports):
         """Return a flattened, sorted, unique list of ports from self.api_ports
@@ -1338,8 +1399,8 @@ class BaseOpenStackCharmAssessStatus(object):
     def check_services_running(self):
         """Check that the services that should be running are actually running.
 
-        This uses the self.services and self.api_ports to determine what should
-        be checked.
+        This uses the self.services and self.active_api_ports to determine what
+        should be checked.
 
         :returns: (status, message) or (None, None).
         """
@@ -1347,7 +1408,7 @@ class BaseOpenStackCharmAssessStatus(object):
         # is not running or the ports are not open.
         _services, _ports = ch_cluster.get_managed_services_and_ports(
             self.services,
-            self.ports_to_check(self.api_ports))
+            self.ports_to_check(self.active_api_ports))
         return os_utils._ows_check_services_running(
             services=_services,
             ports=_ports)
